# Andrew Anderson's utils

session_protocol:
  Contents protocol class (socket subclass), which is designed for safe client-server communications.

dbtools:
  Inspired by jQuery.
  Made for SQL.
  Enjoy.

x_structs:
  Contains implementetions of XDict and XList structs
